Get the content of a classic page from an Opendatasoft platform.
Arguments
- page_slug
Slug of the page (in the backoffice of the platform -> Pages -> New or existing page -> Properties -> Page URL).
Value
A list object containing the information from the page (title, description, tags...).
Examples
if (FALSE) {
page_slug <- "odsrmd-example"
page_elements <- get_ods_page(page_slug)
}